@@ -20,25 +20,38 @@
     "Bioconductor online version validation disabled;
     see ?BIOCONDUCTOR_ONLINE_VERSION_DIAGNOSIS"
 
-.LEGACY_INSTALL_CMD <-
-    "source(\"https://bioconductor.org/biocLite.R\")"
-
 .VERSION_TAGS <-
     c("out-of-date", "release", "devel", "future")
 
 .VERSION_MAP_SENTINEL <- data.frame(
-    Bioc = package_version(list()),
-    R = package_version(list()),
+    Bioc = package_version(character()),
+    R = package_version(character()),
     BiocStatus = factor(
         factor(),
         levels = .VERSION_TAGS
     )
 )
 
+## version-specific options
+
+.version_force_version <-
+    function()
+{
+    ## check R_BIOC_VERSION environment variable
+    force_version <- Sys.getenv("R_BIOC_VERSION", "")
+
+    ## return either NA (do no force version) or the version to use
+    if (nzchar(force_version)) {
+        package_version(force_version)
+    } else {
+        NA
+    }
+}
+
 .version_sentinel <-
     function(msg)
 {
-    version <- package_version(NA, strict = FALSE)
+    version <- package_version(NA_character_, strict = FALSE)
     structure(
         unclass(version),
         msg = msg,
@@ -93,8 +106,11 @@ format.version_sentinel <-
     function(config)
 {
     txt <- tryCatch(.inet_readLines(config), error = identity)
-    if (inherits(txt, "error") && startsWith(config, "https://")) {
-        config <- sub("https", "http", config)
+    if (inherits(txt, "error")) {
+        if (startsWith(config, "https://"))
+            config <- sub("https", "http", config)
+        else if (!startsWith(config, "http"))
+            config <- paste0("file://", config)
         txt <- tryCatch(.inet_readLines(config), error = identity)
     }
     txt
@@ -259,6 +275,12 @@ format.version_sentinel <-
     function(version, map = .version_map(), r_version = .version_R_version(),
              check_future = FALSE)
 {
+    if (!is.na(.version_force_version())) {
+        return(sprintf(
+            "Using environment variable R_BIOC_VERSION = '%s'",
+            version
+        ))
+    }
     if (identical(version, "devel"))
         version <- .version_bioc("devel")
     version <- .package_version(version)
@@ -319,6 +341,9 @@ format.version_sentinel <-
     if (identical(version, "devel"))
         version <- .version_bioc("devel")
     version <- .package_version(version)
+    force_version <- .version_force_version()
+    if (identical(version, force_version))
+        return(version)
 
     txt <- .version_validity(version)
     isTRUE(txt) || ifelse(.is_CRAN_check(), .message(txt), .stop(txt))
@@ -340,10 +365,12 @@ format.version_sentinel <-
         if (.r_version_lt_350())
             return(sprintf(
                 "Bioconductor version '%s' is out-of-date; BiocManager does
-                 not support R version '%s'. For older installations of
-                 Bioconductor, use '%s' and refer to the 'BiocInstaller'
-                 vignette on the Bioconductor website",
-                version, getRversion(), .LEGACY_INSTALL_CMD
+                 not support R version '%s'. Older installations of
+                 Bioconductor are no longer supported as the 'BiocInstaller'
+                 script has been defunct. Use an R version greater than '3.5'
+                 and install the latest version of Bioconductor with
+                'BiocManager'.",
+                version, getRversion()
             ))
         else
             return(sprintf(
@@ -427,6 +454,10 @@ format.version_sentinel <-
 #' when version cannot be validated e.g., because internet access is
 #' not available.
 #'
+#' The environment variable `R_BIOC_VERSION` can be used to specify a
+#' version that is not consistent with *Bioconductor* release
+#' versioning. Use of this variable is strongly discouraged.
+#'
 #' @return A two-digit version, e.g., `3.8`, of class
 #'     `package_version` describing the version of _Bioconductor_ in
 #'     use.
@@ -439,7 +470,9 @@ format.version_sentinel <-
 version <-
     function()
 {
-    bioc <- .version_BiocVersion()
+    bioc <- .version_force_version()
+    if (is.na(bioc))
+        bioc <- .version_BiocVersion()
     if (is.na(bioc))
         bioc <- .version_choose_best()
 
