@@ -153,8 +153,8 @@ test_that(".version_bioc() works", {
     )
 
     ## map misconfiguration
-    with_mock(
-        `BiocManager:::.version_map` = function(...) {
+    with_mocked_bindings(
+        .version_map = function(...) {
             .ver_map
         },
         expect_match(
@@ -166,8 +166,8 @@ test_that(".version_bioc() works", {
     .ver_map <- rbind.data.frame(c("3.9", "4.2", "out-of-date"), .ver_map)
 
     ## all good
-    with_mock(
-        `BiocManager:::.version_map` = function(...) {
+    with_mocked_bindings(
+        .version_map = function(...) {
             .ver_map
         },
         expect_identical(
@@ -178,8 +178,8 @@ test_that(".version_bioc() works", {
     ## type misspecified
     type_miss <-
         "Bioconductor version cannot be validated; is type input misspecified?.*"
-    with_mock(
-        `BiocManager:::.version_map` = function(...) {
+    with_mocked_bindings(
+        .version_map = function(...) {
             .ver_map
         },
         expect_match(
@@ -199,8 +199,8 @@ test_that(".version_R() works", {
         BiocStatus = c("release", "devel", "future")
     )
     ## out-of-date is missing
-    with_mock(
-        `BiocManager:::.version_map` = function(...) {
+    with_mocked_bindings(
+        .version_map = function(...) {
             .ver_map
         },
         expect_match(
@@ -210,8 +210,8 @@ test_that(".version_R() works", {
     )
     .ver_map <- rbind.data.frame(c("3.9", "4.2", "out-of-date"), .ver_map)
     ## all good
-    with_mock(
-        `BiocManager:::.version_map` = function(...) {
+    with_mocked_bindings(
+        .version_map = function(...) {
             .ver_map
         },
         expect_identical(
@@ -219,8 +219,8 @@ test_that(".version_R() works", {
         )
     )
     ## type is misspecified
-    with_mock(
-        `BiocManager:::.version_map` = function(...) {
+    with_mocked_bindings(
+        .version_map = function(...) {
             .ver_map
         },
         expect_match(
@@ -362,8 +362,8 @@ test_that(".version_sentinel() works", {
 })
 
 test_that(".version_BiocVersion returns .version_sentinel output", {
-    with_mock(
-        `BiocManager:::.version_BiocVersion_installed` = function(...) {
+    with_mocked_bindings(
+        .version_BiocVersion_installed = function(...) {
             FALSE
         },
         expect_identical(
@@ -374,8 +374,8 @@ test_that(".version_BiocVersion returns .version_sentinel output", {
 })
 
 test_that(".version_map_get_offline() works", {
-    with_mock(
-        `BiocManager:::.version_BiocVersion` = function(...) {
+    with_mocked_bindings(
+        .version_BiocVersion = function(...) {
             .version_sentinel("BiocVersion is not installed")
         },
         expect_identical(
@@ -387,11 +387,11 @@ test_that(".version_map_get_offline() works", {
     skip_if_offline()
     rver <- package_version("4.3")
     class(rver) <- c("R_system_version", class(rver))
-    with_mock(
-        `BiocManager:::.version_BiocVersion` = function(...) {
+    with_mocked_bindings(
+        .version_BiocVersion = function(...) {
             package_version("3.14")
         },
-        `BiocManager:::.version_R_version` = function(...) {
+        .version_R_version = function(...) {
             rver <- package_version("4.3")
             class(rver) <- c("R_system_version", class(rver))
             rver
@@ -410,16 +410,71 @@ test_that("version chooses best", {
     target_version <-  structure(
         list(c(3L, 17L), class = c("package_version", "numeric_version"))
     )
-    with_mock(
-        `BiocManager:::.version_BiocVersion` = function(...) {
+    with_mocked_bindings(
+        .version_BiocVersion = function(...) {
             .version_sentinel("BiocVersion is not installed")
         },
-        `BiocManager:::.version_choose_best` = function(...) {
+        .version_choose_best = function(...) {
             target_version
         },
         expect_identical(
-            version(),
+            .version_choose_best(),
             target_version
         )
     )
 })
+
+test_that(".version_force_version() works", {
+    skip_if_offline()
+
+    test_version <- "3.16"
+    withr::with_envvar(
+        list(R_BIOC_VERSION = ""),
+        expect_false(identical(version(), package_version(test_version)))
+    )
+    withr::with_envvar(
+        list(R_BIOC_VERSION = ""),
+        expect_true(is.na(.version_force_version()))
+    )
+    withr::with_envvar(
+        list(R_BIOC_VERSION = test_version),
+        expect_identical(
+            .version_force_version(), package_version(test_version)
+        )
+    )
+    withr::with_envvar(
+        list(R_BIOC_VERSION = test_version),
+        expect_identical(version(), package_version(test_version))
+    )
+    withr::with_envvar(
+        list(R_BIOC_VERSION = test_version),
+        expect_identical(
+            .version_validate(test_version),
+            package_version(test_version)
+        )
+    )
+    withr::with_envvar(
+        list(R_BIOC_VERSION = test_version),
+        expect_identical(grep(test_version, repositories()), 1:5)
+    )
+
+    new_lib <- tempfile(); dir.create(new_lib)
+    withr::local_libpaths(new_lib)
+    expect_error(packageVersion("BiocVersion", lib.loc = .libPaths()[1]))
+    ## do *not* install BiocVersion
+    withr::with_envvar(list(R_BIOC_VERSION = test_version), install())
+    expect_error(packageVersion("BiocVersion", lib.loc = .libPaths()[1]))
+    ## install BiocVersion for original version
+    original_version <- version()
+    install("BiocVersion", lib = .libPaths()[1])
+    vers <- packageVersion("BiocVersion", lib.loc = .libPaths()[1])
+    expect_identical(
+        package_version(paste(vers$major, vers$minor, sep = ".")),
+        original_version
+    )
+    ## BiocVersion ignored with R_BIOC_VERSION
+    withr::with_envvar(
+        list(R_BIOC_VERSION = test_version),
+        expect_identical(version(), package_version(test_version))
+    )
+})
